#ifndef _FS_COMPLIANCECOMMON_C_H_
#define _FS_COMPLIANCECOMMON_C_H_

#ifdef __cplusplus
extern "C" {
#endif


FSErrorCode FSDK_ComplianceEngine_Initialize(const wchar_t* compliance_resource_folder_path, const char* compliance_engine_unlockcode);
FSErrorCode FSDK_ComplianceEngine_Release();
FSErrorCode FSDK_ComplianceEngine_SetTempFolderPath(const wchar_t* temp_folder_path);
FSErrorCode FSDK_ComplianceEngine_SetLanguage(const char* language);
struct FSProgressCallback {
  void* user_data;
  void (*Release)(void* user_data);
  void (*UpdateCurrentStateData)(void* user_data, int current_rate, const wchar_t*current_state_string);
  
};


typedef enum _FSFixupState {
e_FSFixupStateSuccess = 0,
e_FSFixupStateFailure = 1,
e_FSFixupStateNotRequired = 2,
}FSFixupState;


struct FSFixupData {
  FS_UINT32 used_count;
  FSFixupState state;
  FS_WSTR name;
  FS_WSTR comment;
  FS_WSTR* reasons_array;
  FS_UINT32 reasons_array_length;
};


typedef enum _FSCheckSeverity {
e_FSCheckSeverityInfo = 1,
e_FSCheckSeverityWarning = 2,
e_FSCheckSeverityError = 3,
}FSCheckSeverity;


struct FSHitData {
  FS_UINT32 triggered_count;
  FSCheckSeverity severity;
  FS_WSTR name;
  FS_WSTR comment;
  FS_WSTR* trigger_values_array;
  FS_UINT32 trigger_values_array_length;
  int page_index;
};

FSErrorCode FSDK_ResultInformation_Create(FS_RESULTINFORMATION_HANDLE& resultinformation_return_value);
FSErrorCode FSDK_ResultInformation_Release(FS_RESULTINFORMATION_HANDLE& resultinformation_handle);
FSErrorCode FSDK_ResultInformation_IsEmpty(FS_RESULTINFORMATION_HANDLE& resultinformation_handle, FS_BOOL& return_value);
FSErrorCode FSDK_ResultInformation_GetFixupDataCount(FS_RESULTINFORMATION_HANDLE& resultinformation_handle, int& return_value);
FSErrorCode FSDK_ResultInformation_GetFixupData(FS_RESULTINFORMATION_HANDLE& resultinformation_handle, int index, FSFixupData& return_value);
FSErrorCode FSDK_ResultInformation_GetHitDataCount(FS_RESULTINFORMATION_HANDLE& resultinformation_handle, int& return_value);
FSErrorCode FSDK_ResultInformation_GetHitData(FS_RESULTINFORMATION_HANDLE& resultinformation_handle, int index, FSHitData& return_value);
#ifdef __cplusplus
}
#endif
#endif
