#ifndef _FS_CONVERT_C_H_
#define _FS_CONVERT_C_H_

#ifdef __cplusplus
extern "C" {
#endif



typedef enum _FSHTML2PDFPageMode {
e_FSPageModeSinglePage  = 0,
e_FSPageModeMultiplePage = 1,
}FSHTML2PDFPageMode;


struct FSHTML2PDFSettingData {
  float          page_width;
  float          page_height;
  FS_BOOL           is_to_page_scale;
  FSRectF          page_margin;
  FSRotation       rotate_degrees;
  FS_BOOL           is_convert_link;
  FS_BOOL           is_generate_tag;
  FSHTML2PDFPageMode page_mode;
  FS_BOOL           to_generate_bookmarks;
};

struct FSTXT2PDFSettingData {
  float page_width;
  float page_height;
  FSRectF page_margin;
  FS_FONT_HANDLE font;
  float text_size;
  FS_ARGB text_color;
  float linespace;
  FS_BOOL is_break_page;
};


typedef enum _FSConvertOptimizeOption {
e_FSConvertOptimizeOptionForPrint  = 0,
e_FSConvertOptimizeOptionForOnScreen = 1,
}FSConvertOptimizeOption;



typedef enum _FSConvertContentOption {
e_FSConvertContentOptionOnlyContent  = 0,
e_FSConvertContentOptionWithMarkup = 1,
}FSConvertContentOption;



typedef enum _FSConvertBookmarkOption {
e_FSConvertBookmarkOptionNone  = 0,
e_FSConvertBookmarkOptionUseHeadings = 1,
e_FSConvertBookmarkOptionUseWordBookmark = 2,
}FSConvertBookmarkOption;


struct FSWord2PDFSettingData {
  FS_BOOL include_doc_props;
  FSConvertOptimizeOption optimize_option;
  FSConvertContentOption content_option;
  FSConvertBookmarkOption bookmark_option;
  FS_BOOL convert_to_pdfa;
};


typedef enum _FSConvertQuality {
e_FSConvertQualityStandard  = 0,
e_FSConvertQualityMinimum = 1,
}FSConvertQuality;



typedef enum _FSScaleType {
e_FSScaleTypeNone  = 0,
e_FSScaleTypeFitAllColumns = 1,
e_FSScaleTypeFitAllRows = 2,
e_FSScaleTypeFitSheet = 3,
}FSScaleType;


struct FSExcel2PDFSettingData {
  FS_BOOL include_doc_props;
  FSConvertQuality quality;
  FS_BOOL ignore_print_area;
  FSScaleType scale_type;
  FS_BOOL convert_to_pdfa;
};


typedef enum _FSConvertIntent {
e_FSConvertIntentPrint  = 0,
e_FSConvertIntentScreen = 1,
}FSConvertIntent;



typedef enum _FSHandoutOrder {
e_FSHandoutOrderHorizontalFirst  = 0,
e_FSHandoutOrderVerticalFirst = 1,
}FSHandoutOrder;



typedef enum _FSOutputType {
e_FSOutputSlides = 1,
e_FSOutputNotesPages = 2,
e_FSOutputOutline = 3,
e_FSOutputOneSlideHandouts = 4,
e_FSOutputTwoSlideHandouts = 5,
e_FSOutputThreeSlideHandouts = 6,
e_FSOutputFourSlideHandouts = 7,
e_FSOutputSixSlideHandouts = 8,
e_FSOutputNineSlideHandouts = 9,
}FSOutputType;


struct FSPowerPoint2PDFSettingData {
  FSConvertIntent intent;
  FS_BOOL frame_output_slides;
  FSOutputType output_type;
  FSHandoutOrder handout_order;
  FS_BOOL output_hidden_slides;
  FS_BOOL include_doc_props;
};

FSErrorCode FSDK_Convert_FromHTML(const wchar_t* src_html, const wchar_t* engine_path, const wchar_t* cookies_path, const FSHTML2PDFSettingData& setting_data, const wchar_t* saved_pdf_path, FS_INT32 timeout);
FSErrorCode FSDK_Convert_FromHTML0(const wchar_t* src_html, const wchar_t* engine_path, FSReaderCallback* cookies_reader, const FSHTML2PDFSettingData& setting_data, const wchar_t* saved_pdf_path, FS_INT32 timeout);
FSErrorCode FSDK_Convert_FromTXT(const wchar_t* src_txt, const wchar_t* saved_pdf_path, const FSTXT2PDFSettingData& setting_data);
FSErrorCode FSDK_Convert_FromWord(const wchar_t* src_word_file_path, const wchar_t* src_file_password, const wchar_t* saved_pdf_path, const FSWord2PDFSettingData& setting_data);
FSErrorCode FSDK_Convert_FromExcel(const wchar_t* src_excel_file_path, const wchar_t* src_file_password, const wchar_t* saved_pdf_path, const FSExcel2PDFSettingData& setting_data);
FSErrorCode FSDK_Convert_FromPowerPoint(const wchar_t* src_ppt_file_path, const wchar_t* src_file_password, const wchar_t* saved_pdf_path, const FSPowerPoint2PDFSettingData& setting_data);
#ifdef __cplusplus
}
#endif
#endif
